@@ -8,23 +8,25 @@
 #'   a single point or regional request.  See section on \dQuote{Rate Limiting}
 #'   for more.
 #'
-#' @param community A case-insensitive character vector providing community name:
-#'   \dQuote{AG}, \dQuote{RE} or \dQuote{SB}.  See argument details for more.
+#' @param community A case-insensitive character vector providing community
+#'   name: \dQuote{AG}, \dQuote{RE} or \dQuote{SB}.  See argument details for
+#'   more.
 #' @param pars  case-insensitive character vector of solar, meteorological or
-#'   climatology parameters to download.  When requesting a single point of x, y
-#'   coordinates, a maximum of twenty (20) `pars` can be specified at one time,
-#'   for \dQuote{daily}, \dQuote{monthly} and \dQuote{climatology}
+#'   climatology parameters to download.  When requesting a single point of x,
+#'   y coordinates, a maximum of twenty (20) `pars` can be specified at one
+#'   time, for \dQuote{daily}, \dQuote{monthly} and \dQuote{climatology}
 #'   `temporal_api`s.  If the `temporal_api` is specified as \dQuote{hourly}
 #'   only 15 `pars` can be specified in a single query.  See `temporal_api` for
 #'   more.  These values are checked internally for validity before sending the
 #'   query to the \acronym{POWER} \acronym{API}.
-#' @param temporal_api A case-insensitive character vector providing the temporal
-#'   \acronym{API} end-point for data being queried, supported values are
-#'   \dQuote{hourly}, \dQuote{daily}, \dQuote{monthly} or \dQuote{climatology}.
-#'   Defaults to \dQuote{daily}.  See argument details for more.
-#' @param lonlat A numeric vector of geographic coordinates for a cell or region
-#'   entered as x, y (longitude, latitude) coordinates.  See argument details
+#' @param temporal_api A case-insensitive character vector providing the
+#'   temporal \acronym{API} end-point for data being queried, supported values
+#'   are \dQuote{hourly}, \dQuote{daily}, \dQuote{monthly} or
+#'   \dQuote{climatology}. Defaults to \dQuote{daily}.  See argument details
 #'   for more.
+#' @param lonlat A numeric vector of geographic coordinates for a cell or
+#'   region entered as x, y (longitude, latitude) coordinates.  See argument
+#'   details for more.
 #' @param dates A character vector of start and end dates in that order,\cr
 #'   _e.g._, `dates = c("1983-01-01", "2017-12-31")`.
 #'   Not used when\cr `temporal_api` is set to \dQuote{climatology}.
@@ -35,16 +37,17 @@
 #'   single point of x, y coordinates, not for use with \dQuote{global} or with
 #'   a regional request.
 #' @param wind_elevation A user-supplied value for elevation at a single point
-#'   in metres.  Wind Elevation values are required to be between 10 and 300
-#'   metres.  Only used with `lonlat` as a single point of x, y coordinates, not
-#'   for use with \dQuote{global} or with a regional request.  If this parameter
-#'   is provided, the `wind_surface` parameter is required with the request, see
-#'    <https://power.larc.nasa.gov/docs/methodology/meteorology/wind/>.
+#'   in metres.  Wind elevation values are required to be between 10 and 300
+#'   metres.  Only used with `lonlat` as a single point of x, y coordinates,
+#'   not for use with \dQuote{global} or with a regional request.  If this
+#'   parameter is provided, the `wind_surface` parameter is required with the
+#'   request, see
+#'   <https://power.larc.nasa.gov/docs/methodology/meteorology/wind/>.
 #' @param wind_surface A user-supplied wind surface for which the corrected
 #'   wind-speed is to be supplied.  See `wind-surface` section for more detail.
 #' @param time_standard \acronym{POWER} provides two different time standards.
-#'    * Universal Time Coordinated (\acronym{UTC}): is the standard time measure
-#'     that used by the world.
+#'    * Universal Time Coordinated (\acronym{UTC}): is the standard time-
+#'      measure that used by the world.
 #'    * Local Solar Time (\acronym{LST}): A 15 degree swath that represents
 #'     solar noon at the middle longitude of the swath.
 #'    Defaults to `LST`.
@@ -58,8 +61,8 @@
 #'  contains industry-friendly parameters formatted for input to crop models.}
 #'
 #'  \item{sb}{Provides access to the Sustainable Buildings Archive, which
-#'  contains industry-friendly parameters for the buildings community to include
-#'  parameters in multi-year monthly averages.}
+#'  contains industry-friendly parameters for the buildings community to
+#'  include parameters in multi-year monthly averages.}
 #'
 #'  \item{re}{Provides access to the Renewable Energy Archive, which contains
 #'  parameters specifically tailored to assist in the design of solar and wind
@@ -79,9 +82,9 @@
 #'
 #' @section Argument details for `lonlat`:
 #' \describe{
-#'  \item{For a single point}{To get a specific cell, 1/2 x 1/2 degree, supply a
-#'  length-two numeric vector giving the decimal degree longitude and latitude
-#'  in that order for data to download,\cr
+#'  \item{For a single point}{To get a specific cell, 1/2 x 1/2 degree, supply
+#'  a length-two numeric vector giving the decimal degree longitude and
+#'  latitude in that order for data to download,\cr
 #'  _e.g._, `lonlat = c(-179.5, -89.5)`.}
 #'
 #'  \item{For regional coverage}{To get a region, supply a length-four numeric
@@ -142,7 +145,7 @@
 #'   if the data are exported to a file format other than a native \R data
 #'   format, *e.g.*, .Rdata, .rda or .rds.
 #'
-#' @return A data frame as a `POWER.Info` class, an extension of the
+#' @returns A data frame as a `POWER.Info` class, an extension of the
 #' [tibble::tibble], object of \acronym{POWER} data including location, dates
 #' (not including \dQuote{climatology}) and requested parameters; a decorative
 #' header of metadata is included in this object.
@@ -189,15 +192,16 @@
 #' @author Adam H. Sparks \email{adamhsparks@@gmail.com}
 #'
 #' @export
-get_power <- function(community = c("ag", "re", "sb"),
-                      pars,
-                      temporal_api = c("daily", "monthly", "hourly", "climatology"),
-                      lonlat,
-                      dates = NULL,
-                      site_elevation = NULL,
-                      wind_elevation = NULL,
-                      wind_surface = NULL,
-                      time_standard = c("LST", "UTC")) {
+get_power <- function(
+    community = c("ag", "re", "sb"),
+    pars,
+    temporal_api = c("daily", "monthly", "hourly", "climatology"),
+    lonlat,
+    dates = NULL,
+    site_elevation = NULL,
+    wind_elevation = NULL,
+    wind_surface = NULL,
+    time_standard = c("LST", "UTC")) {
   community <- tolower(community)
   temporal_api <- tolower(temporal_api)
   time_standard <- toupper(time_standard)
@@ -256,9 +260,11 @@ get_power <- function(community = c("ag", "re", "sb"),
 
   # extract query results and return to user -----------------------------------
   # create meta object
-  power_data <- readr::read_lines(I(response$parse("UTF8")))
+  power_data <- readr::read_lines(I(response$parse()))
 
-  meta <- power_data[c(grep("-BEGIN HEADER-", power_data):grep("-END HEADER-", power_data))]
+  meta <- power_data[c(
+    grep("-BEGIN HEADER-", power_data):grep("-END HEADER-", power_data)
+  )]
   # strip BEGIN/END HEADER lines
   meta <- meta[-c(1, max(length(meta)))]
 
@@ -273,7 +279,7 @@ get_power <- function(community = c("ag", "re", "sb"),
 
   # create tibble object
   power_data <- readr::read_csv(
-    I(response$parse("UTF8")),
+    I(response$parse()),
     col_types = readr::cols(),
     na = c("-999", "-999.00", "-999.0", "-99", "-99.00", "-99.0"),
     skip = length(meta) + 2
@@ -288,18 +294,26 @@ get_power <- function(community = c("ag", "re", "sb"),
   )
 
   # if the temporal average is anything but climatology, add date fields
-  if (temporal_api == "daily" &&
-    query_list$community == "re" ||
-    query_list$community == "sb") {
+  if (
+    temporal_api == "daily" &&
+      query_list$community == "re" ||
+      query_list$community == "sb"
+  ) {
     power_data <- .format_dates_re_sb(power_data)
   }
-  if (temporal_api == "daily" &&
-    query_list$community == "ag") {
+  if (
+    temporal_api == "daily" &&
+      query_list$community == "ag"
+  ) {
     power_data <- .format_dates_ag(power_data)
   }
 
   # add new class
-  power_data <- tibble::new_tibble(power_data, class = "POWER.Info", nrow = nrow(power_data))
+  power_data <- tibble::new_tibble(
+    power_data,
+    class = "POWER.Info",
+    nrow = nrow(power_data)
+  )
 
   # add attributes for printing df
   attr(power_data, "POWER.Info") <- meta[1]
@@ -323,12 +337,12 @@ get_power <- function(community = c("ag", "re", "sb"),
 #' @param lonlat User entered `lonlat` value.
 #' @param temporal_api User entered `temporal_api` value.
 #'
-#' @return Validated dates in a list for use in `.build_query`.
-#' @keywords internal
-#' @noRd
+#' @returns Validated dates in a list for use in `.build_query`.
+#' @dev
 .check_dates <- function(dates, lonlat, temporal_api) {
   if (is.null(dates) & temporal_api != "climatology") {
-    cli::cli_abort(c(i = "You have not entered dates for the query."),
+    cli::cli_abort(
+      c(i = "You have not entered dates for the query."),
       call = rlang::caller_env()
     )
   }
@@ -346,8 +360,10 @@ get_power <- function(community = c("ag", "re", "sb"),
       dates <- unique(substr(dates, 1, 4))
     }
     if (dates[[2]] < dates[[1]]) {
-      cli::cli_alert_info(c(i = "Your start and end dates were reversed.
-                                They have been reordered."))
+      cli::cli_alert_info(c(
+        i = "Your start and end dates were reversed.
+                                They have been reordered."
+      ))
       dates <- c(dates[2], dates[1])
     }
     return(dates)
@@ -374,14 +390,26 @@ get_power <- function(community = c("ag", "re", "sb"),
     date_format <- function(x) {
       rlang::try_fetch(
         # try to parse the date format using lubridate
-        x <- lubridate::parse_date_time(x, c(
-          "Ymd", "dmY", "mdY", "BdY", "Bdy", "bdY", "bdy"
-        )),
+        x <- lubridate::parse_date_time(
+          x,
+          c(
+            "Ymd",
+            "dmY",
+            "mdY",
+            "BdY",
+            "Bdy",
+            "bdY",
+            "bdy"
+          )
+        ),
         warning = function(c) {
           cli::cli_abort(
             call = rlang::caller_env(),
-            c(i = "{.var {x}} is not a valid entry for a date value.", x = "Enter as 'YYYY-MM-DD' (ISO8601 format) and check that it
-                is a valid date.")
+            c(
+              i = "{.var {x}} is not a valid entry for a date value.",
+              x = "Enter as 'YYYY-MM-DD' (ISO8601 format) and check that it
+                is a valid date."
+            )
           )
         }
       )
@@ -393,30 +421,45 @@ get_power <- function(community = c("ag", "re", "sb"),
 
     # if the stdate is > endate, flip order
     if (dates[[2]] < dates[[1]]) {
-      cli::cli_alert_info(c(i = "Your start and end dates were reversed.
-                              They have been reordered."))
+      cli::cli_alert_info(c(
+        i = "Your start and end dates were reversed.
+                              They have been reordered."
+      ))
       dates <- c(dates[2], dates[1])
     }
 
     # check date to be sure it's not before POWER data start
-    if (temporal_api != "hourly" &&
-      dates[[1]] < "1981-01-01") {
+    if (
+      temporal_api != "hourly" &&
+        dates[[1]] < "1981-01-01"
+    ) {
       cli::cli_abort(
         call = rlang::caller_env(),
-        c(i = "{.arg dates} = {.val {dates[[1]]}} is an invalid value.", x = "1981-01-01 is the earliest available data from POWER.")
+        c(
+          i = "{.arg dates} = {.val {dates[[1]]}} is an invalid value.",
+          x = "1981-01-01 is the earliest available data from POWER."
+        )
       )
-    } else if (temporal_api == "hourly" &
-      dates[[1]] < "2001-01-01") {
+    } else if (
+      temporal_api == "hourly" &
+        dates[[1]] < "2001-01-01"
+    ) {
       cli::cli_abort(
         call = rlang::caller_env(),
-        c(i = "{.arg dates} = {.val {dates[[1]]}} is an invalid value.", x = "2001-01-01 is the earliest available hourly data from POWER.")
+        c(
+          i = "{.arg dates} = {.val {dates[[1]]}} is an invalid value.",
+          x = "2001-01-01 is the earliest available hourly data from POWER."
+        )
       )
     }
     # check end date to be sure it's not _after_
     if (dates[[2]] > Sys.Date()) {
       cli::cli_abort(
         call = rlang::caller_env(),
-        c(i = "{.arg dates} = {.val {dates[[2]]}} is invalid.", x = "The weather data cannot possibly extend beyond this day.")
+        c(
+          i = "{.arg dates} = {.val {dates[[2]]}} is invalid.",
+          x = "The weather data cannot possibly extend beyond this day."
+        )
       )
     }
 
@@ -426,20 +469,22 @@ get_power <- function(community = c("ag", "re", "sb"),
 }
 
 #' Check User Inputs for get_power for Validity
-#' @param community A case-insensitive character vector providing community name:
-#'   \dQuote{AG}, \dQuote{RE} or \dQuote{SB}.  See argument details for more.
+#' @param community A case-insensitive character vector providing community
+#'   name: \dQuote{AG}, \dQuote{RE} or \dQuote{SB}.  See argument details for
+#'   more.
 #' @param pars  case-insensitive character vector of solar, meteorological or
-#'   climatology parameters to download.  When requesting a single point of x, y
-#'   coordinates, a maximum of twenty (20) `pars` can be specified at one time,
-#'   for \dQuote{daily}, \dQuote{monthly} and \dQuote{climatology}
+#'   climatology parameters to download.  When requesting a single point of x,
+#'   y coordinates, a maximum of twenty (20) `pars` can be specified at one
+#'   time, for \dQuote{daily}, \dQuote{monthly} and \dQuote{climatology}
 #'   `temporal_api`s.  If the `temporal_api` is specified as \dQuote{hourly}
 #'   only 15 `pars` can be specified in a single query.  See `temporal_api` for
 #'   more.  These values are checked internally for validity before sending the
 #'   query to the \acronym{POWER} \acronym{API}.
-#' @param temporal_api A case-insensitive character vector providing the temporal
-#'   \acronym{API} end-point for data being queried, supported values are
-#'   \dQuote{hourly}, \dQuote{daily}, \dQuote{monthly} or \dQuote{climatology}.
-#'   Defaults to \dQuote{daily}.  See argument details for more.
+#' @param temporal_api A case-insensitive character vector providing the
+#'   temporal \acronym{API} end-point for data being queried, supported values
+#'   are \dQuote{hourly}, \dQuote{daily}, \dQuote{monthly} or
+#'   \dQuote{climatology}. Defaults to \dQuote{daily}.  See argument details
+#'   for more.
 #' @param lonlat A numeric vector of geographic coordinates for a cell or region
 #'   entered as x, y (longitude, latitude) coordinates.  See argument details
 #'   for more.
@@ -449,37 +494,41 @@ get_power <- function(community = c("ag", "re", "sb"),
 #'   single point of x, y coordinates, not for use with \dQuote{global} or with
 #'   a regional request.
 #' @param wind_elevation A user-supplied value for elevation at a single point
-#'   in metres.  Wind Elevation values in Meters are required to be between 10 m
-#'   and 300 m.  Only used with `lonlat` as a single point of x, y coordinates,
-#'   not for use with \dQuote{global} or with a regional request.  If this
-#'   parameter is provided, the `wind_surface` parameter is required with the
-#'   request, see
+#'   in metres.  Wind Elevation values in Meters are required to be between
+#'   10 m and 300 m.  Only used with `lonlat` as a single point of x, y
+#'   coordinates, not for use with \dQuote{global} or with a regional request.
+#'   If this parameter is provided, the `wind_surface` parameter is required
+#'   with the request, see
 #'    <https://power.larc.nasa.gov/docs/methodology/meteorology/wind/>.
 #' @param wind_surface A user-supplied wind surface for which the corrected
 #'   wind-speed is to be supplied.  See `wind-surface` section for more detail.
-#' @return Nothing, called for its side-effects of checking user inputs.
-#' @keywords Internal
-#' @noRd
+#' @returns Nothing, called for its side-effects of checking user inputs.
+#' @dev
 
-.check_inputs <- function(community,
-                          lonlat,
-                          pars,
-                          site_elevation,
-                          temporal_api,
-                          wind_elevation,
-                          wind_surface) {
+.check_inputs <- function(
+    community,
+    lonlat,
+    pars,
+    site_elevation,
+    temporal_api,
+    wind_elevation,
+    wind_surface) {
   if (any(tolower(lonlat) == "global")) {
     # remove this if POWER enables global queries for climatology again
     cli::cli_abort(
-      c(x = "The POWER team have not enabled {.var global} data queries with
-        this version of the 'API'."),
+      c(
+        x = "The POWER team have not enabled {.var global} data queries with
+        this version of the 'API'."
+      ),
       call = rlang::caller_env()
     )
   }
   if (!is.null(site_elevation) && !is.numeric(site_elevation)) {
     cli::cli_abort(
-      c(x = "You have entered an invalid value for {.arg site_elevation},
-         {.val site_elevation}."),
+      c(
+        x = "You have entered an invalid value for {.arg site_elevation},
+         {.val site_elevation}."
+      ),
       call = rlang::caller_env()
     )
   }
@@ -506,6 +555,17 @@ get_power <- function(community = c("ag", "re", "sb"),
     wind_elevation <- NULL
   }
 
+  if (length(lonlat) > 2 && length(pars) > 1) {
+    cli::cli_abort(
+      c(
+        x = "You have provided more than one parameter for a regional request.",
+        i = "The latest version of the API does not allow more than one parameter for regional requests.",
+        "Please provide only one parameter for a regional request."
+      ),
+      call = rlang::caller_env()
+    )
+  }
+
   if (is.character(wind_surface) && is.null(wind_elevation)) {
     cli::cli_abort(
       c(
@@ -517,11 +577,16 @@ get_power <- function(community = c("ag", "re", "sb"),
     )
   }
 
-  if (!is.null(wind_elevation) && (!is.numeric(wind_elevation) ||
-    (wind_elevation %notin% 10:300))) {
+  if (
+    !is.null(wind_elevation) &&
+      (!is.numeric(wind_elevation) ||
+        (wind_elevation %notin% 10:300))
+  ) {
     cli::cli_abort(
-      c(x = "{.arg wind_elevation} values in metres are required to be between
-          10 and 300 metres inclusive."),
+      c(
+        x = "{.arg wind_elevation} values in metres are required to be between
+          10 and 300 metres inclusive."
+      ),
       call = rlang::caller_env()
     )
   }
@@ -542,8 +607,10 @@ get_power <- function(community = c("ag", "re", "sb"),
 
   if (temporal_api == "hourly" && length(lonlat) == 4L) {
     cli::cli_abort(
-      c(x = "{.arg temporal_api} does not support hourly values for
-                     regional queries."),
+      c(
+        x = "{.arg temporal_api} does not support hourly values for
+                     regional queries."
+      ),
       call = rlang::caller_env()
     )
   }
@@ -551,14 +618,20 @@ get_power <- function(community = c("ag", "re", "sb"),
   if (length(pars) > 15 && temporal_api == "hourly") {
     cli::cli_abort(
       call = rlang::caller_env(),
-      c(x = "A maximum of 15 parameters can currently be requested in one
-        submission for hourly data.", i = "You have submitted {.val {length(pars)}}"),
+      c(
+        x = "A maximum of 15 parameters can currently be requested in one
+        submission for hourly data.",
+        i = "You have submitted {.val {length(pars)}}"
+      ),
     )
   } else if (length(pars) > 20) {
     cli::cli_abort(
       call = rlang::caller_env(),
-      c(x = "A maximum of 20 parameters can currently be requested in one
-        submission.", i = "You have submitted {.val {length(pars)}}")
+      c(
+        x = "A maximum of 20 parameters can currently be requested in one
+        submission.",
+        i = "You have submitted {.val {length(pars)}}"
+      )
     )
   }
 }
@@ -572,9 +645,8 @@ get_power <- function(community = c("ag", "re", "sb"),
 #' @param lonlat User entered `lonlat` value.
 #' @param pars User entered `pars` value.
 #'
-#' @return A list called `lonlat_identifier` for use in [.build_query()].
-#' @keywords internal
-#' @noRd
+#' @returns A list called `lonlat_identifier` for use in [.build_query()].
+#' @dev
 .check_lonlat <-
   function(lonlat, pars) {
     bbox <- NULL
@@ -591,16 +663,22 @@ get_power <- function(community = c("ag", "re", "sb"),
       if (lonlat[1] < -180 | lonlat[1] > 180) {
         cli::cli_abort(
           call = rlang::caller_env(),
-          c(i = "Please check your longitude, {.var {lonlat[1]}},
-                         to be sure it is valid.")
+          c(
+            i = "Please check your longitude, {.var {lonlat[1]}},
+                         to be sure it is valid."
+          )
         )
       }
-      if (lonlat[2] < -90 |
-        lonlat[2] > 90) {
+      if (
+        lonlat[2] < -90 |
+          lonlat[2] > 90
+      ) {
         cli::cli_abort(
           call = rlang::caller_env(),
-          c(i = "Please check your latitude, {.val {lonlat[2]}},
-          value to be sure it is valid.")
+          c(
+            i = "Please check your latitude, {.val {lonlat[2]}},
+          value to be sure it is valid."
+          )
         )
       }
       identifier <- "point"
@@ -616,33 +694,49 @@ get_power <- function(community = c("ag", "re", "sb"),
             5 x 5 region of 1 degree values, ({.emph i.e.}, 100 points total)."
           )
         )
-      } else if (any(lonlat[1] < -180 |
-        lonlat[3] < -180 |
-        lonlat[1] > 180 |
-        lonlat[3] > 180)) {
-        cli::cli_abort(
-          call = rlang::caller_env(),
-          c(i = "Please check your longitude values, {.var {lonlat[1]}} and
-            {.var {lonlat[3]}}, to be sure they are valid.")
+      } else if (
+        any(
+          lonlat[1] < -180 |
+            lonlat[3] < -180 |
+            lonlat[1] > 180 |
+            lonlat[3] > 180
         )
-      } else if (any(lonlat[2] < -90 |
-        lonlat[4] < -90 |
-        lonlat[2] > 90 |
-        lonlat[4] > 90)) {
+      ) {
         cli::cli_abort(
           call = rlang::caller_env(),
-          c(i = "Please check your latitude values, {.var {lonlat[2]}} and
-          {.var {lonlat[4]}}, to be sure they are valid.")
+          c(
+            i = "Please check your longitude values, {.var {lonlat[1]}} and
+            {.var {lonlat[3]}}, to be sure they are valid."
+          )
+        )
+      } else if (
+        any(
+          lonlat[2] < -90 |
+            lonlat[4] < -90 |
+            lonlat[2] > 90 |
+            lonlat[4] > 90
+        )
+      ) {
+        cli::cli_abort(
+          call = rlang::caller_env(),
+          c(
+            i = "Please check your latitude values, {.var {lonlat[2]}} and
+          {.var {lonlat[4]}}, to be sure they are valid."
+          )
         )
       } else if (lonlat[2] > lonlat[4]) {
         cli::cli_abort(
           call = rlang::caller_env(),
-          c(i = "The first `lonlat` {.arg lat} value must be the minimum value.")
+          c(
+            i = "The first `lonlat` {.arg lat} value must be the minimum value."
+          )
         )
       } else if (lonlat[1] > lonlat[3]) {
         cli::cli_abort(
           call = rlang::caller_env(),
-          c(i = "The first `lonlat` {.arg lon} value must be the minimum value.")
+          c(
+            i = "The first `lonlat` {.arg lon} value must be the minimum value."
+          )
         )
       }
       identifier <- "regional"
@@ -655,8 +749,10 @@ get_power <- function(community = c("ag", "re", "sb"),
     } else {
       cli::cli_abort(
         call = rlang::caller_env(),
-        c(i = "You have entered an invalid request for `lonlat`
-          {.arg {lonlat}}.")
+        c(
+          i = "You have entered an invalid request for `lonlat`
+          {.arg {lonlat}}."
+        )
       )
     }
 
@@ -676,25 +772,26 @@ get_power <- function(community = c("ag", "re", "sb"),
 
 #' Construct a list of options to pass to the POWER API
 #'
-#' @param community A validated value for community from [check_community()].
-#' @param lonlat_identifier A list of values, a result of [check_lonlat()].
-#' @param pars A validated value from [check_pars()].
-#' @param dates A list of values, a result of [check_dates()]..
+#' @param community A validated value for community from [.check_community].
+#' @param lonlat_identifier A list of values, a result of [.check_lonlat].
+#' @param pars A validated value from [.check_pars].
+#' @param dates A list of values, a result of [.check_dates]..
 #' @param site_elevation A validated value passed by `check_inputs`.
 #' @param wind_elevation A validated value passed by `check_inputs`.
 #' @param wind_surface A validated value passed by `check_inputs`.
-#' @return A `list` object of values to be passed to a [crul] object to query
+#' @returns A `list` object of values to be passed to a \CRANpkg{crul} object to
+#'  query
 #'  the 'POWER' 'API'.
-#' @keywords internal
-#' @noRd
-.build_query <- function(community,
-                         lonlat_identifier,
-                         pars,
-                         dates,
-                         site_elevation,
-                         wind_elevation,
-                         wind_surface,
-                         time_standard) {
+#' @dev
+.build_query <- function(
+    community,
+    lonlat_identifier,
+    pars,
+    dates,
+    site_elevation,
+    wind_elevation,
+    wind_surface,
+    time_standard) {
   user_agent <- "nasapower4r"
 
   if (lonlat_identifier$identifier == "point") {
@@ -746,12 +843,11 @@ get_power <- function(community = c("ag", "re", "sb"),
 #'
 #' Formats columns as integers for DOY and adds columns for year, month and day.
 #'
-#' @param power_response A tidy data.frame resulting from [build_query()].
+#' @param power_response A tidy data.frame resulting from [.build_query].
 #'
-#' @return A tidy data frame of 'POWER' data with additional date information
+#' @returns A tidy data frame of 'POWER' data with additional date information
 #'   columns.
-#' @keywords internal
-#' @noRd
+#' @dev
 
 .format_dates_ag <- function(power_response) {
   # convert DOY to integer
@@ -760,19 +856,33 @@ get_power <- function(community = c("ag", "re", "sb"),
   # Calculate the full date from YEAR and DOY
   power_response <- tibble::add_column(
     power_response,
-    YYYYMMDD = as.Date(power_response$DOY - 1, origin = as.Date(paste0(
-      power_response$YEAR, "-01-01"
-    ))),
+    YYYYMMDD = as.Date(
+      power_response$DOY - 1,
+      origin = as.Date(paste0(
+        power_response$YEAR,
+        "-01-01"
+      ))
+    ),
     .after = "DOY"
   )
 
   # Extract month as integer
-  power_response <- tibble::add_column(power_response, MM = as.integer(substr(power_response$YYYYMMDD, 6, 7)), .after = "YEAR")
+  power_response <- tibble::add_column(
+    power_response,
+    MM = as.integer(substr(power_response$YYYYMMDD, 6, 7)),
+    .after = "YEAR"
+  )
 
   # Extract day as integer
-  return(tibble::add_column(power_response, DD = as.integer(substr(
-    power_response$YYYYMMDD, 9, 10
-  )), .after = "MM"))
+  return(tibble::add_column(
+    power_response,
+    DD = as.integer(substr(
+      power_response$YYYYMMDD,
+      9,
+      10
+    )),
+    .after = "MM"
+  ))
 }
 
 #' Format date columns in POWER data frame for the re community
@@ -781,10 +891,9 @@ get_power <- function(community = c("ag", "re", "sb"),
 #'
 #' @param power_response A tidy data.frame resulting from [.build_query()].
 #'
-#' @return A tidy data frame of 'POWER' data with additional date information
+#' @returns A tidy data frame of 'POWER' data with additional date information
 #'   columns.
-#' @keywords internal
-#' @noRd
+#' @dev
 
 .format_dates_re_sb <- function(power_response) {
   names(power_response)[names(power_response) == "DY"] <- "DD"
