@@ -19,7 +19,7 @@
 #'
 #' @author Adam H. Sparks, \email{adamhsparks@@gmail.com}
 #'
-#' @return A [list] object of information on parameter groupings in the
+#' @returns A [list] object of information on parameter groupings in the
 #'   \acronym{POWER} \acronym{API}.
 #'
 #' @export
@@ -42,13 +42,13 @@ query_groupings <- function(global = FALSE) {
       .send_mgmt_query(.url = power_url)
 
     response$raise_for_status()
-    return(jsonlite::fromJSON(response$parse("UTF8")))
+    return(yyjsonr::read_json_raw(response$content))
   } else {
     power_url <- sprintf("%s/global", power_url)
     response <-
       .send_mgmt_query(.url = power_url)
 
     response$raise_for_status()
-    return(jsonlite::fromJSON(response$parse("UTF8")))
+    return(yyjsonr::read_json_raw(response$content))
   }
 }
